parse_with_feature_flags

Function parse_with_feature_flags 

pub fn parse_with_feature_flags(
    text: &str,
    options: &ParseOptions,
    feature_flags: &FeatureFlags,
) -> Result<Schema>
Parse a COBOL copybook text into a schema with specific options

Errors

Returns an error if the copybook contains syntax errors or unsupported features.