parse_with_options

Function parse_with_options 

pub fn parse_with_options(text: &str, options: &ParseOptions) -> Result<Schema>
Parse a COBOL copybook text into a schema with specific options

Errors

Returns an error if the copybook contains syntax errors or unsupported features.