pub fn parse_with_feature_flags(
text: &str,
options: &ParseOptions,
feature_flags: &FeatureFlags,
) -> Result<Schema>Expand description
Parse a COBOL copybook text into a schema with specific options
Errors
Returns an error if the copybook contains syntax errors or unsupported features.